Struct limine_protocol::requests::EntryPointRequest
source · [−]#[repr(C)]pub struct EntryPointRequest {
pub id: [u64; 4],
pub revision: u64,
pub response: Option<NonNull<EntryPointResponse>>,
pub entry: Option<*mut ()>,
}Expand description
Request the bootloader use the specified entry point instead of the default one
Fields
id: [u64; 4]ID Array
revision: u64Revision numbers
response: Option<NonNull<EntryPointResponse>>Response pointer
entry: Option<*mut ()>Function to the entry point
Implementations
sourceimpl EntryPointRequest
impl EntryPointRequest
sourcepub const ID: [u64; 4] = [COMMON_MAGIC[0], COMMON_MAGIC[1], 1430011643342672865, 3102041752378475114]
pub const ID: [u64; 4] = [COMMON_MAGIC[0], COMMON_MAGIC[1], 1430011643342672865, 3102041752378475114]
The ID of the request
sourcepub fn new() -> EntryPointRequest
pub fn new() -> EntryPointRequest
Return a new instance of the item with the correct ID values
sourcepub const fn into_request(self) -> LimineRequest<Self>
pub const fn into_request(self) -> LimineRequest<Self>
Convert the request into a LimineRequest