Struct limine_protocol::requests::KernelAddressRequest
source · [−]#[repr(C)]pub struct KernelAddressRequest {
pub id: [u64; 4],
pub revision: u64,
pub response: Option<NonNull<KernelAddressResponse>>,
}Expand description
Request the physical and virtual address of the Kernel
Fields
id: [u64; 4]ID Array
revision: u64Revision numbers
response: Option<NonNull<KernelAddressResponse>>Response pointer
Implementations
sourceimpl KernelAddressRequest
impl KernelAddressRequest
sourcepub const ID: [u64; 4] = [COMMON_MAGIC[0], COMMON_MAGIC[1], 8194992790871301987, 12854480912826934407]
pub const ID: [u64; 4] = [COMMON_MAGIC[0], COMMON_MAGIC[1], 8194992790871301987, 12854480912826934407]
The ID of the request
sourcepub fn new() -> KernelAddressRequest
pub fn new() -> KernelAddressRequest
Return a new instance of the item with the correct ID values
sourcepub const fn into_request(self) -> LimineRequest<Self>
pub const fn into_request(self) -> LimineRequest<Self>
Convert the request into a LimineRequest