Struct limine_protocol::requests::StackSizeRequest
source · [−]#[repr(C)]pub struct StackSizeRequest {
pub id: [u64; 4],
pub revision: u64,
pub response: Option<NonNull<StackSizeResponse>>,
pub stack_size: u64,
}Expand description
Specify how much stack you desire the bootloader to give you
Fields
id: [u64; 4]ID Array
revision: u64Revision numbers
response: Option<NonNull<StackSizeResponse>>Response pointer
stack_size: u64The amount of stack to request
Implementations
sourceimpl StackSizeRequest
impl StackSizeRequest
sourcepub const ID: [u64; 4] = [COMMON_MAGIC[0], COMMON_MAGIC[1], 2472177429088471334, 16270115406302603837]
pub const ID: [u64; 4] = [COMMON_MAGIC[0], COMMON_MAGIC[1], 2472177429088471334, 16270115406302603837]
The ID of the request
sourcepub fn new() -> StackSizeRequest
pub fn new() -> StackSizeRequest
Return a new instance of the item with the correct ID values
sourcepub const fn into_request(self) -> LimineRequest<Self>
pub const fn into_request(self) -> LimineRequest<Self>
Convert the request into a LimineRequest