#[repr(C)]
pub struct TerminalResponse { pub revision: u64, pub terminal_count: u64, pub terminals: *const *const Terminal, pub write: TerminalWriteFn, }
Response to [TerminalRequest]

Fields

revision: u64

The response revision number

terminal_count: u64

The number of Terminals in terminals

terminals: *const *const Terminal

A pointer to an array of Terminal pointers

write: TerminalWriteFn

The terminal write function

Important

It must be noted that this is the physical address of the write function

Implementations

Get the terminal slice

Safety

The pointer must point to a valid array of Terminals

Get the terminal slice

Safety

The pointer must point to a valid array of Terminals. Additionally, you must ensure that this is called nowhere else, otherwise very, very bad things may occur due to read and write tearing