#[repr(C)]
pub struct File<'a> {
Show 13 fields pub revision: u64, pub address: *const u8, pub size: u64, pub path: &'a CStr, pub cmdline: &'a CStr, pub media_type: FileType, pub tftp_ip: u32, pub tftp_port: u32, pub partition_index: u32, pub mbr_disk_id: u32, pub gpt_disk_uuid: UUID, pub gpt_part_uuid: UUID, pub part_uuid: UUID, /* private fields */
}
File structure

Fields

revision: u64

Revision of the File structure

address: *const u8

The address of the file

size: u64

The size of the file

path: &'a CStr

The path of the file

cmdline: &'a CStr

A command line associated with the file

media_type: FileType

The kind of media the file is on

tftp_ip: u32

IP of the TFTP server, if one was used

tftp_port: u32

Port of the TFTP server, if one was used

partition_index: u32

!-based partition index of the volume from which the file was loaded

mbr_disk_id: u32

If non-zero, the ID of the disk from the MBR

gpt_disk_uuid: UUID

The UUID of the disk from which the file was loaded from GPT, if it is non-zero

gpt_part_uuid: UUID

The UUID of the partition from which the file was loaded from GPT, if it is non-zero

part_uuid: UUID

The UUID of the filesystem frmo which the file was laoded from GPT, if it is non-zero,