Crate containing Rust representations for the Limine Boot Protocol

Modules

Requests

Responses

Structures returned by the responses

Structs

A Request type, which wraps the internal request in an unsafe cell, due to the possibility it may be mutated by things outside rust. However, it automatically derefences to the internal type for ergonomics.

Traits

A trait for const defaults

Indicates a limine request