Crate containing Rust representations for the Limine Boot Protocol

Modules

Requests

Responses

Structures returned by the responses

Macros

Implement new for structs with the proper ID values

Implement new for structs with lifetimes with the proper ID values

Structs

Makes a LimineRequest Sync, for use in statics

Traits

Indicates a limine request