Requests

Structs

Request the time on boot

Get information regarding the bootloader

Request the address of the EFI System Table

Request the bootloader use the specified entry point instead of the default one

Request a framebuffer

Request Higher Half Direct Mapping be enabled

Request the physical and virtual address of the Kernel

Request the file the Kernel was loaded from

Request Level 5 paging be enabled

Request for receiving the Memory Map from the bootloader

Request the loaded modules

Request the address of the RSDP

Request the SMBIOS entry point

Request the bootloader bootstrap the secondary processors

Specify how much stack you desire the bootloader to give you

Request a terminal