#[repr(transparent)]
pub struct Request<T>(pub UnsafeCell<T>);
A Request type, which wraps the internal request in an unsafe cell, due to the possibility it may be mutated by things outside rust. However, it automatically derefences to the internal type for ergonomics.

Tuple Fields

0: UnsafeCell<T>