Enum limine_protocol::structures::terminal::CallbackType
source · [−]#[repr(u64)]
pub enum CallbackType {
DECSequence,
Bell,
DECPrivateID,
StatusReport,
CursorPositionReport,
KeyboardLEDUpdate,
SwitchSequence,
LinuxEscapeSequence,
}Expand description
Types of terminal callbacks
Variants
DECSequence
A DEC Private Mode Sequence has been encountered
Bell
A bell event has occurred
DECPrivateID
The kernel must respond to a DEC Private ID request
StatusReport
The kernel must respond to an ECMA-48 status report request
CursorPositionReport
The kernel must respond to an ECMA-48 cursor position report request
KeyboardLEDUpdate
The kernel must respond to a keyboard LED change request
SwitchSequence
An ECMA-48 Switch sequence has been encountered that the terminal cannot handle alone
LinuxEscapeSequence
A private Linux escape sequence has been encountered that the terminal cannot handle alone